=== modified file 'qpdfview-application.pro'
--- qpdfview-application.pro	2013-01-16 18:34:48 +0000
+++ qpdfview-application.pro	2013-01-17 14:49:07 +0000
@@ -138,6 +138,11 @@
     SOURCES += synctex/synctex_parser.c synctex/synctex_parser_utils.c
 }
 
+!without_magic {
+    DEFINES += WITH_MAGIC
+    LIBS += -lmagic
+}
+
 !without_signals {
     DEFINES += WITH_SIGNALS
 

=== modified file 'sources/documentview.cpp'
--- sources/documentview.cpp	2013-01-17 13:27:22 +0000
+++ sources/documentview.cpp	2013-01-17 14:49:07 +0000
@@ -53,6 +53,12 @@
 
 #endif // WITH_SYNCTEX
 
+#ifdef WITH_MAGIC
+
+#include <magic.h>
+
+#endif // WITH_MAGIC
+
 #include "model.h"
 #include "pageitem.h"
 #include "searchthread.h"
@@ -1429,12 +1435,63 @@
 
 Model::Document* DocumentView::loadDocument(const QString& filePath)
 {
+    enum { UnknownType = 0, PDF = 1, PS = 2, DjVu = 3 } fileType = UnknownType;
+
+#ifdef WITH_MAGIC
+
+    magic_t cookie = magic_open(MAGIC_MIME_TYPE);
+
+    if(magic_load(cookie, 0) == 0)
+    {
+        const char* mime_type = magic_file(cookie, QFile::encodeName(filePath));
+
+        if(qstrncmp(mime_type, "application/pdf", 15) == 0)
+        {
+            fileType = PDF;
+        }
+        else if(qstrncmp(mime_type, "application/postscript", 22) == 0)
+        {
+            fileType = PS;
+        }
+        else if(qstrncmp(mime_type, "image/vnd.djvu", 14) == 0)
+        {
+            fileType = DjVu;
+        }
+        else
+        {
+            qDebug() << "Unknown file type:" << mime_type;
+        }
+    }
+
+    magic_close(cookie);
+
+#else
+
     QFileInfo fileInfo(filePath);
 
-#ifdef WITH_PDF
-
     if(fileInfo.suffix().toLower() == "pdf")
     {
+        fileType = PDF;
+    }
+    else if(fileInfo.suffix().toLower() == "ps")
+    {
+        fileType = PS;
+    }
+    else if(fileInfo.suffix().toLower() == "djvu" || fileInfo.suffix().toLower() == "djv")
+    {
+        fileType = DjVu;
+    }
+    else
+    {
+        qDebug() << "Unkown file type:" << fileInfo.suffix().toLower();
+    }
+
+#endif // WITH_MAGIC
+
+#ifdef WITH_PDF
+
+    if(fileType == PDF)
+    {
         if(s_pdfDocumentLoader == 0)
         {
 #ifndef STATIC_PDF_PLUGIN
@@ -1462,7 +1519,7 @@
 
 #ifdef WITH_PS
 
-    if(fileInfo.suffix().toLower() == "ps")
+    if(fileType == PS)
     {
         if(s_psDocumentLoader == 0)
         {
@@ -1492,7 +1549,7 @@
 
 #ifdef WITH_DJVU
 
-    if(fileInfo.suffix().toLower() == "djvu" || fileInfo.suffix().toLower() == "djv")
+    if(fileType == DjVu)
     {
         if(s_djvuDocumentLoader == 0)
         {

